package cn.breeze.elleai.test;

import cn.breeze.elleai.application.dto.langchain.VectorSearchRequest;
import cn.breeze.elleai.application.dto.langchain.VectorSegment;
import cn.breeze.elleai.application.service.AIService;
import cn.breeze.elleai.infra.entity.KbEntity;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.context.annotation.Profile;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@SpringBootTest
@Profile("dev")
public class AIServiceTestUnit {


    @Autowired
    private AIService aiService;

    /**
     * 同步知识库到向量数据库, 实例只是一条，需要根据实际业务场景进行修改
     */
    @Test
    public void testSyncKBtoVectorDb() {
        KbEntity kbEntity = new KbEntity();
        kbEntity.setId(1L);
        kbEntity.setQuestion("问题");
        kbEntity.setAnswer("答案");
        kbEntity.setTagId(2L);

        VectorSegment vectorSegment = new VectorSegment();
        vectorSegment.setContent(kbEntity.getQuestion() + "\n" + kbEntity.getAnswer());
        Map<String, Object> metadata = new HashMap<>();
        metadata.put("kb_id", kbEntity.getId());
        metadata.put("tag_id", kbEntity.getTagId());
        metadata.put("question", kbEntity.getQuestion());
        metadata.put("answer", kbEntity.getAnswer());
        vectorSegment.setMetadata(metadata);
        aiService.addVectorSegments(List.of(vectorSegment));
    }


    /**
     * 根据tagId删除向量数据库中的数据
     */
    @Test
    public void testRemoveByTagId() {
        Map<String, Object> metadata = new HashMap<>();
        metadata.put("tag_id", 2L);
        aiService.removeAll(metadata);
    }


    /**
     * 根据segmentId删除向量数据库中的数据
     */
    @Test
    public void testRemoveBySegmentId() {
        aiService.removeSegments(List.of("1"));
    }


    @Test
    public void testSearch() {
        VectorSegment vectorSegment = new VectorSegment();
        vectorSegment.setContent("问题");
        //元数据放进来的数据会作为 filter条件，支持等于或在列表中
        Map<String, Object> metadata = new HashMap<>();
        metadata.put("tag_id", 2L); //筛选某个分类
        metadata.put("tag_id", List.of(2L,3L,4L)); //在多个分类列表中
        vectorSegment.setMetadata(metadata);
        VectorSearchRequest request = VectorSearchRequest.builder()
                .query(vectorSegment.getContent())
                .topK(10)
                .minScore(0.5)
                .metadata(vectorSegment.getMetadata())
                .build();
        List<VectorSegment> vectorSegments = aiService.search(request);

    }

}
